pub struct ReadStreamOptions {
pub block: Option<Duration>,
pub count: Option<u64>,
}Expand description
Options for XREAD command
Fields
block: Option<Duration>count: Option<u64>Trait Implementations
Sourceimpl Clone for ReadStreamOptions
impl Clone for ReadStreamOptions
Sourcefn clone(&self) -> ReadStreamOptions
fn clone(&self) -> ReadStreamOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadStreamOptions
impl Debug for ReadStreamOptions
Sourceimpl Default for ReadStreamOptions
impl Default for ReadStreamOptions
Sourcefn default() -> ReadStreamOptions
fn default() -> ReadStreamOptions
Returns the “default value” for a type. Read more
Sourceimpl ToRedisArgs for &ReadStreamOptions
impl ToRedisArgs for &ReadStreamOptions
Sourcefn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
fn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
This writes the value into a vector of bytes. Each item
is a single argument. Most items generate a single item. Read more
Sourcefn to_redis_args(&self) -> Vec<Vec<u8>>
fn to_redis_args(&self) -> Vec<Vec<u8>>
This converts the value into a vector of bytes. Each item
is a single argument. Most items generate a vector of a
single item. Read more
Sourcefn describe_numeric_behavior(&self) -> NumericBehavior
fn describe_numeric_behavior(&self) -> NumericBehavior
Returns an information about the contained value with regards
to it’s numeric behavior in a redis context. This is used in
some high level concepts to switch between different implementations
of redis functions (for instance
INCR vs INCRBYFLOAT).Sourcefn is_single_arg(&self) -> bool
fn is_single_arg(&self) -> bool
Returns an indiciation if the value contained is exactly one
argument. It returns false if it’s zero or more than one. This
is used in some high level functions to intelligently switch
between
GET and MGET variants.impl Copy for ReadStreamOptions