pub struct WriteStreamOptions {
pub disable_create: bool,
pub capacity: Option<(Trim, TrimPrecision)>,
}Expand description
Options for XADD command
Fields
disable_create: boolcapacity: Option<(Trim, TrimPrecision)>Trait Implementations
Sourceimpl Clone for WriteStreamOptions
impl Clone for WriteStreamOptions
Sourcefn clone(&self) -> WriteStreamOptions
fn clone(&self) -> WriteStreamOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WriteStreamOptions
impl Debug for WriteStreamOptions
Sourceimpl Default for WriteStreamOptions
impl Default for WriteStreamOptions
Sourcefn default() -> WriteStreamOptions
fn default() -> WriteStreamOptions
Returns the “default value” for a type. Read more
Sourceimpl ToRedisArgs for &WriteStreamOptions
impl ToRedisArgs for &WriteStreamOptions
Sourcefn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
fn write_redis_args<W>(&self, out: &mut W)where
W: ?Sized + RedisWrite,
This writes the value into a vector of bytes. Each item
is a single argument. Most items generate a single item. Read more
Sourcefn to_redis_args(&self) -> Vec<Vec<u8>>
fn to_redis_args(&self) -> Vec<Vec<u8>>
This converts the value into a vector of bytes. Each item
is a single argument. Most items generate a vector of a
single item. Read more
Sourcefn describe_numeric_behavior(&self) -> NumericBehavior
fn describe_numeric_behavior(&self) -> NumericBehavior
Returns an information about the contained value with regards
to it’s numeric behavior in a redis context. This is used in
some high level concepts to switch between different implementations
of redis functions (for instance
INCR vs INCRBYFLOAT).Sourcefn is_single_arg(&self) -> bool
fn is_single_arg(&self) -> bool
Returns an indiciation if the value contained is exactly one
argument. It returns false if it’s zero or more than one. This
is used in some high level functions to intelligently switch
between
GET and MGET variants.impl Copy for WriteStreamOptions